@@ -6,7 +6,6 @@ from io import StringIO
 from pcapparser.config import OutputLevel
 # print http req/resp
 from pcapparser import utils
-from pcapparser.processor import HttpDataProcessor
 from pcapparser import config
 
 
@@ -17,27 +16,36 @@ def _get_full_url(uri, host):
         return b'http://' + host + uri
 
 
-class HttpPrinter(HttpDataProcessor):
+class HttpPrinter(object):
     def __init__(self, client_host, remote_host):
         self.parse_config = config.get_config()
         self.buf = StringIO()
+        self.client_host = client_host
+        self.remote_host = remote_host
+        self.printed = False
+
+    def _print_connection(self):
         self._println(('*' * 10 + " [%s:%d] -- -- --> [%s:%d] " + '*' * 10) %
-                      (client_host[0], client_host[1], remote_host[0], remote_host[1]))
+                      (self.client_host[0], self.client_host[1], self.remote_host[0],
+                       self.remote_host[1]))
 
     def on_http_req(self, req_header, req_body):
         """
         :type req_header: HttpRequestHeader
         :type req_body: bytes
         """
+        if not self.printed:
+            self._print_connection()
+            self.printed = True
+
         if self.parse_config.level == OutputLevel.ONLY_URL:
-            self._println(
-                req_header.method + b" " + _get_full_url(req_header.uri, req_header.host))
+            self._println(req_header.method + b" " + _get_full_url(req_header.uri, req_header.host))
         elif self.parse_config.level == OutputLevel.HEADER:
             self._println(req_header.raw_data)
-            self._println('')
+            self._println()
         elif self.parse_config.level >= OutputLevel.TEXT_BODY:
             self._println(req_header.raw_data)
-            self._println('')
+            self._println()
 
             mime, charset = utils.parse_content_type(req_header.content_type)
             # usually charset is not set in http post
@@ -49,7 +57,7 @@ class HttpPrinter(HttpDataProcessor):
                 # someone missed the content-encoding header
                 req_header.gzip = utils.gzipped(req_body)
             if output_body:
-                self._print_body(req_body, req_header.gzip, charset)
+                self._print_body(req_body, req_header.gzip, mime, charset)
                 self._println('')
 
     def on_http_resp(self, resp_header, resp_body):
@@ -61,10 +69,10 @@ class HttpPrinter(HttpDataProcessor):
             self._println(resp_header.status_line)
         elif self.parse_config.level == OutputLevel.HEADER:
             self._println(resp_header.raw_data)
-            self._println('')
+            self._println()
         elif self.parse_config.level >= OutputLevel.TEXT_BODY:
             self._println(resp_header.raw_data)
-            self._println('')
+            self._println()
 
             mime, charset = utils.parse_content_type(resp_header.content_type)
             # usually charset is not set in http post
@@ -76,14 +84,14 @@ class HttpPrinter(HttpDataProcessor):
                 # someone missed the content-encoding header
                 resp_header.gzip = utils.gzipped(resp_body)
             if output_body:
-                self._print_body(resp_body, resp_header.gzip, charset)
-                self._println('')
+                self._print_body(resp_body, resp_header.gzip, mime, charset)
+                self._println()
 
     def _if_output(self, mime):
         return self.parse_config.level >= OutputLevel.ALL_BODY and not utils.is_binary(mime) \
                or self.parse_config.level >= OutputLevel.TEXT_BODY and utils.is_text(mime)
 
-    def _println(self, line):
+    def _println(self, line=''):
         if type(line) == type(b''):
             line = line.decode('utf-8')
         self.buf.write(line)
@@ -93,14 +101,26 @@ class HttpPrinter(HttpDataProcessor):
         if self.parse_config.level >= level:
             self._println(line)
 
-    def _print_body(self, body, gzipped, charset):
+    def _print_body(self, body, gzipped, mime, charset):
         if gzipped:
             body = utils.ungzip(body)
 
         content = utils.decode_body(body, charset)
         if content:
+            if not mime:
+                # guess mime...
+                if content.startswith('{') and content.endswith('}') or content.startswith('[') \
+                        and content.endswith(']'):
+                    mime = b'application/json'
+            if mime is None:
+                mime = ''
             if self.parse_config.pretty:
-                utils.try_print_json(content, self.buf)
+                if b'json' in mime:
+                    utils.try_print_json(content, self.buf)
+                elif b'www-form-urlencoded' in mime:
+                    utils.try_decoded_print(content, self.buf)
+                else:
+                    self.buf.write(content)
             else:
                 self.buf.write(content)
             self.buf.write('\n')
